@@ -23,33 +23,21 @@
 #define EXTRACT_PRINCE_H
 
 #include "tool.h"
+#include "utils.h"
 #include "common/array.h"
 
+class Databank;
+
 class ExtractPrince : public Tool {
 public:
 	ExtractPrince(const std::string &name = "extract_prince");
-	
+
 	virtual void execute();
-	
+
 	virtual InspectionMatch inspectInput(const Common::Filename &filename);
-	
+
 protected:
-	struct FileEntry {
-		std::string _name;
-		uint32 _offset;
-		uint32 _size;
-	};
-
-	struct FileData {
-		byte *_fileTable;
-		uint32 _size;
-	};
-
-	byte *openDatabank();
-	static void decrypt(byte *buffer, uint32 size);
-
-	FileData loadFile(int itemIndex);
-	FileData loadFile(std::string fileName);
+	FileData loadFile(const std::string &fileName);
 	char correctPolishLetter(char c);
 
 	void exportMobs(FileData fileData);
@@ -61,18 +49,9 @@ protected:
 	byte *talkTxtNoDialog(byte *talkTxt);
 	bool printSpecialDialogData(byte c);
 
-	Common::Array<FileEntry> _items;
-	Common::File _databank, _fFiles;
-};
+	Common::File _fFiles;
 
-class Decompressor {
-public:
-	void decompress(byte *source, byte *dest, uint32 destSize);
-protected:
-	byte *_src, *_dst;
-	byte _bitBuffer;
-	int _bitsLeft;
-	int getBit();
+	Databank *_databank;
 };
 
 #endif
